@@ -239,7 +239,7 @@ regpenEM <- function(y, X, w, lambda, order, D)
     I.lambda.D <- (1+lambda*UDU$values)
            edf <- sum(1/I.lambda.D)
          y_Hy2 <- y.y-2*sum((yy^2)/I.lambda.D)+sum((yy^2)/((I.lambda.D)^2))
-           GCV <- (n*y_Hy2)/(n-k*edf)
+           GCV <- (n*y_Hy2)/(n-k*edf)^2
            GCV
            }  
 #--------------------------------------------------
@@ -378,6 +378,7 @@ startLambdaName <- as.character(attr(x, "NameForLambda"))
       #  lambda <- if (sign(edf_df(0))==sign(edf_df(100000))) 100000  # in case they have the some sign
       #            else  uniroot(edf_df, c(0,100000))$root
       #method 2 from Simon Wood (2006) pages 210-211, and 360 
+    browser()
            QR <- qr(sqrt(w)*X)
          Rinv <- solve(qr.R(QR))
           S   <- t(D)%*%D
